==> knative-model-6.1.0-sources.jar: io/fabric8/knative/flows/v1/ParallelListFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ParallelListFluent<A extends ParallelListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,Parallel item);
  public A setToItems(Integer index,Parallel item);
  public A addToItems(io.fabric8.knative.flows.v1.Parallel... items);
  public A addAllToItems(Collection<Parallel> items);
  public A removeFromItems(io.fabric8.knative.flows.v1.Parallel... items);
  public A removeAllFromItems(Collection<Parallel> items);
  public A removeMatchingFromItems(Predicate<ParallelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Parallel> getItems();
  public List<Parallel> buildItems();
  public Parallel buildItem(Integer index);
  public Parallel buildFirstItem();
  public Parallel buildLastItem();
  public Parallel buildMatchingItem(Predicate<ParallelBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ParallelBuilder> predicate);
  public A withItems(List<Parallel> items);
  public A withItems(io.fabric8.knative.flows.v1.Parallel... items);
  public Boolean hasItems();
  public ParallelListFluent.ItemsNested<A> addNewItem();
  public ParallelListFluent.ItemsNested<A> addNewItemLike(Parallel item);
  public ParallelListFluent.ItemsNested<A> setNewItemLike(Integer index,Parallel item);
  public ParallelListFluent.ItemsNested<A> editItem(Integer index);
  public ParallelListFluent.ItemsNested<A> editFirstItem();
  public ParallelListFluent.ItemsNested<A> editLastItem();
  public ParallelListFluent.ItemsNested<A> editMatchingItem(Predicate<ParallelBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ParallelFluent<ParallelListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/flows/v1/ParallelListFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ParallelListFluent<A extends ParallelListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,Parallel item);
  public A setToItems(int index,Parallel item);
  public A addToItems(io.fabric8.knative.flows.v1.Parallel... items);
  public A addAllToItems(Collection<Parallel> items);
  public A removeFromItems(io.fabric8.knative.flows.v1.Parallel... items);
  public A removeAllFromItems(Collection<Parallel> items);
  public A removeMatchingFromItems(Predicate<ParallelBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Parallel> getItems();
  public List<Parallel> buildItems();
  public Parallel buildItem(int index);
  public Parallel buildFirstItem();
  public Parallel buildLastItem();
  public Parallel buildMatchingItem(Predicate<ParallelBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ParallelBuilder> predicate);
  public A withItems(List<Parallel> items);
  public A withItems(io.fabric8.knative.flows.v1.Parallel... items);
  public Boolean hasItems();
  public ParallelListFluent.ItemsNested<A> addNewItem();
  public ParallelListFluent.ItemsNested<A> addNewItemLike(Parallel item);
  public ParallelListFluent.ItemsNested<A> setNewItemLike(int index,Parallel item);
  public ParallelListFluent.ItemsNested<A> editItem(int index);
  public ParallelListFluent.ItemsNested<A> editFirstItem();
  public ParallelListFluent.ItemsNested<A> editLastItem();
  public ParallelListFluent.ItemsNested<A> editMatchingItem(Predicate<ParallelBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ParallelFluent<ParallelListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
